@@ -63,22 +63,8 @@ def pytest_terminal_summary(terminalreporter, exitstatus, config):
 
 pytest_ini_content = """[pytest]
 markers =
-    smoke: smoke test
-    regress: regress test
-"""
-
-fixture_admin_content = """#!/usr/bin/python
-# encoding=utf-8
-
-\"\"\" Can only be modified by the administrator. Only fixtures are provided.
-\"\"\"
-
-from tep.fixture import *
-
-
-@pytest.fixture
-def common_created_by_admin():
-    pass
+    smoke: 冒烟测试
+    regress: 回归测试
 """
 
 fixture_env_vars_content = """#!/usr/bin/python
@@ -96,16 +82,16 @@ def env_vars(config):
         \"\"\"变量定义开始\"\"\"
         # 环境变量
         mapping = {
-            \"qa\": {
-                "domain": "http://127.0.0.1:5000",
+            "qa": {  # qa环境
+                "domain": "http://127.0.0.1:5000",  # 变量名:变量值
                 "mysql_engine": mysql_engine("127.0.0.1",  # host
                                              "2306",  # port
                                              "root",  # username
                                              "123456",  # password
-                                             "qa"),  # db_name
+                                             "qa"),  # dbname
             },
-            "release": {
-                "domain": "https://release.com",
+            "release": {  # release环境
+                "domain": "https://release.com",  # 变量名:变量值
                 "mysql_engine": mysql_engine("127.0.0.1",
                                              "2306",
                                              "root",
@@ -114,7 +100,7 @@ def env_vars(config):
             }
             # 继续添加
         }
-        # 定义类属性，敲代码时会有智能提示
+        # 定义类属性，敲代码时会自动补全
         domain = mapping[env]["domain"]
         mysql_engine = mapping[env]["mysql_engine"]
         \"\"\"变量定义结束\"\"\"
@@ -132,7 +118,7 @@ def _jwt_headers(token):
 
 @pytest.fixture(scope="session")
 def login(env_vars):
-    # Code your login
+    # 封装登录接口
     logger.info("Administrator login")
     response = request(
         "post",
@@ -153,65 +139,6 @@ def login(env_vars):
     return Clazz
 """
 
-fixture_your_name_content = """#!/usr/bin/python
-# encoding=utf-8
-
-\"\"\" Please define your own fixture.
-\"\"\"
-
-from tep.fixture import *
-
-
-@pytest.fixture(scope="session")
-def env_vars_your_name(config):
-    class Clazz:
-        env = config["env"]
-
-        # Environment and variables
-        mapping = {
-            "qa": {
-                "your_var": "123",
-            },
-            "release": {
-                "your_var": "456",
-            }
-            # Add your environment and variables
-        }
-        # Define properties for auto display
-        your_var = mapping[env]["your_var"]
-
-    return Clazz()
-
-
-@pytest.fixture
-def share_your_name():
-    pass
-"""
-
-fixture_second_content = """#!/usr/bin/python
-# encoding=utf-8
-
-
-from tep.fixture import *
-
-
-@pytest.fixture
-def fixture_second():
-    logger.info("fixture_second")
-"""
-
-fixture_three_content = """#!/usr/bin/python
-# encoding=utf-8
-
-
-from tep.fixture import *
-
-
-@pytest.fixture
-def fixture_three():
-    logger.info("fixture_three")
-"""
-
 test_login_content = """from loguru import logger
 
 
@@ -219,32 +146,6 @@ def test_login(login):
     logger.info(login.token)
 """
 
-test_post_content = """import jmespath
-from loguru import logger
-
-from tep.client import request
-
-
-def test_post(faker_ch, url, login):
-    # description
-    logger.info("test post")
-    # data
-    fake = faker_ch
-    # request
-    response = request(
-        "post",
-        url=url("/api/users"),
-        headers=login.jwt_headers,
-        json={
-            "name": fake.name()
-        }
-    )
-    # assert
-    assert response.status_code < 400
-    # extract
-    user_id = jmespath.search("id", response.json())
-"""
-
 test_mysql_content = """from loguru import logger
 from tep.dao import print_db_table
 
@@ -254,14 +155,39 @@ def test_mysql(pd, env_vars):
     logger.info(print_db_table(data))
 """
 
-test_request_content = """from tep.client import request
+test_request_content = """from urllib.parse import urlencode
 
-request("get", url="", headers={}, json={})
-request("post", url="", headers={}, params={})
-request("put", url="", headers={}, json={})
-request("delete", url="", headers={})
+from tep.client import request
 
-# upload excel
+# -------------------------------get开始-------------------------------
+# 不带参数
+request("get", url="/api/xxx", headers={})
+# json参数
+request("get", url="/api/xxx", headers={}, params={})
+# queryset
+request("get", url="/api/xxx?a=1&b=2", headers={})
+# json转queryset
+query = {}
+request("get", url="/api/xxx" + "?" + urlencode(query), headers={})
+# -------------------------------get结束-------------------------------
+
+# -------------------------------post开始-------------------------------
+# json参数
+request("post", url="/api/xxx", headers={}, json={})
+
+# dict参数
+request("post", url="/api/xxx", headers={}, data={})
+# -------------------------------post结束-------------------------------
+
+# -------------------------------put开始-------------------------------
+request("put", url="/api/xxx", headers={}, json={})
+# -------------------------------post结束-------------------------------
+
+# -------------------------------delete开始-------------------------------
+request("delete", url=f"/api/xxx", headers={})
+# -------------------------------delete结束-------------------------------
+
+# -------------------------------上传excel开始-------------------------------
 file_name = ""
 file_path = ""
 request("post",
@@ -276,6 +202,7 @@ request("post",
         },
         verify=False
         )
+# -------------------------------上传excel结束-------------------------------
 """
 
 fastapi_mock_content = """#!/usr/bin/python
@@ -340,7 +267,6 @@ import time
 import allure
 from loguru import logger
 from tep import client
-from tep.client import TepResponse
 
 
 def request_monkey_patch(req, *args, **kwargs):
@@ -377,7 +303,7 @@ def request_monkey_patch(req, *args, **kwargs):
         logger.error("request failed")
     except TypeError:
         logger.warning(log4a)
-    return TepResponse(response)
+    return response
 
 
 def request(method, url, **kwargs):
@@ -389,7 +315,7 @@ test_login_pay_content = """import jmespath
 from tep.client import request
 
 \"\"\"
-测试登录到下单流程，需要先运行utils/flask_mock_api.py
+测试登录到下单流程，需要先运行utils/fastapi_mock.py
 \"\"\"
 
 
@@ -437,80 +363,6 @@ def test(env_vars, login):
     assert response.json()["success"] == "true"
 """
 
-test_login_pay_httprunner_content = """from httprunner import HttpRunner, Config, Step, RunRequest
-
-\"\"\"
-测试登录到下单流程，需要先运行utils/flask_mock_api.py
-\"\"\"
-
-
-class TestLoginPay(HttpRunner):
-    config = (
-        Config("登录到下单流程")
-            .variables(
-            **{
-                "skuNum": "3"
-            }
-        )
-            .base_url("http://127.0.0.1:5000")
-    )
-
-    teststeps = [
-        Step(
-            RunRequest("登录")
-                .post("/login")
-                .with_headers(**{"Content-Type": "application/json"})
-                .with_json({"username": "dongfanger", "password": "123456"})
-                .extract()
-                .with_jmespath("body.token", "token")
-                .validate()
-                .assert_equal("status_code", 200)
-        ),
-        Step(
-            RunRequest("搜索商品")
-                .get("searchSku?skuName=电子书")
-                .with_headers(**{"token": "$token"})
-                .extract()
-                .with_jmespath("body.skuId", "skuId")
-                .with_jmespath("body.price", "skuPrice")
-                .validate()
-                .assert_equal("status_code", 200)
-        ),
-        Step(
-            RunRequest("添加购物车")
-                .post("/addCart")
-                .with_headers(**{"Content-Type": "application/json",
-                                 "token": "$token"})
-                .with_json({"skuId": "$skuId", "skuNum": "$skuNum"})
-                .extract()
-                .with_jmespath("body.totalPrice", "totalPrice")
-                .validate()
-                .assert_equal("status_code", 200)
-        ),
-        Step(
-            RunRequest("下单")
-                .post("/order")
-                .with_headers(**{"Content-Type": "application/json",
-                                 "token": "$token"})
-                .with_json({"skuId": "$skuId", "price": "$skuPrice", "skuNum": "$skuNum", "totalPrice": "$totalPrice"})
-                .extract()
-                .with_jmespath("body.orderId", "orderId")
-                .validate()
-                .assert_equal("status_code", 200)
-        ),
-        Step(
-            RunRequest("支付")
-                .post("/pay")
-                .with_headers(**{"Content-Type": "application/json",
-                                 "token": "$token"})
-                .with_json({"orderId": "$orderId", "payAmount": "6.9"})
-                .validate()
-                .assert_equal("status_code", 200)
-                .assert_equal("body.success", "true")
-        ),
-    ]
-"""
-
 Login_content = """from tep.client import BaseRequest
 
 
@@ -598,14 +450,14 @@ class Pay(BaseRequest):
 
 test_login_pay_mvc_content = """from tep.fixture import TepVars
 
-from services.AddCart import AddCart
-from services.Login import Login
-from services.Order import Order
-from services.Pay import Pay
-from services.SearchSku import SearchSku
+from samples.login_pay.mvc.services.AddCart import AddCart
+from samples.login_pay.mvc.services.Login import Login
+from samples.login_pay.mvc.services.Order import Order
+from samples.login_pay.mvc.services.Pay import Pay
+from samples.login_pay.mvc.services.SearchSku import SearchSku
 
 \"\"\"
-测试登录到下单流程，需要先运行utils / flask_mock_api.py
+测试登录到下单流程，需要先运行utils / fastapi_mock.py
 \"\"\"
 
 
@@ -629,14 +481,6 @@ class Test:
         Pay(Test).post()
 """
 
-test_multi_fixture_content = """#!/usr/bin/python
-# encoding=utf-8
-
-
-def test(fixture_second, fixture_three):
-    pass
-"""
-
 test_request_monkey_patch_content = """from utils.http_client import request
 
 
@@ -671,13 +515,15 @@ mitm_dir = os.path.join(tests_dir, "mitm")
 if not os.path.exists(mitm_dir):
     os.mkdir(mitm_dir)
 # 当前时间作为文件名
-filename = time.strftime("%Y%m%d_%H_%M_%S", time.localtime()) + ".py"
+filename = f'test_{time.strftime("%Y%m%d_%H%M%S", time.localtime())}.py'
 case_file = os.path.join(mitm_dir, filename)
 # 生成用例文件
-template = \"\"\"from tep.client import request
+template = \"\"\"import allure
+from tep.client import request
 
 
-def test():
+@allure.title("")
+def test(env_vars):
 \"\"\"
 if not os.path.exists(case_file):
     with open(case_file, "w", encoding="utf8") as fw:
@@ -720,7 +566,7 @@ class Record:
         else:
             body_grammar = f"json={body}"
         return f\"\"\"
-    # 接口描述
+    # 描述
     # 数据
     # 请求
     response = request(
@@ -729,8 +575,7 @@ class Record:
         headers={headers},
         {body_grammar}
     )
-    # 数据提取
-    # var = response.jmespath("expression")
+    # 提取
     # 断言
     assert response.status_code < 400
 \"\"\"
@@ -750,10 +595,34 @@ addons = [
 
 \"\"\"
 ==================================命令说明开始==================================
-# 正向代理
+# 正向代理（需要手动打开代理）
 mitmdump -s mitm.py
 # 反向代理
 mitmdump -s mitm.py --mode reverse:http://127.0.0.1:5000 --listen-host 127.0.0.1 --listen-port 8000
 ==================================命令说明结束==================================
 \"\"\"
-"""
\ No newline at end of file
+"""
+
+structure_content = """项目结构说明：
+files：文件
+fixtures：pytest fixture
+reports：allure测试报告
+samples：示例代码
+  db：数据库
+    test_mysql.py：连接MySQL
+  http：requests请求
+    test_request.py：requests常见用法
+    test_request_monkey_patch.py：tep request猴子补丁测试
+  login_pay：登陆到下单流程
+    mvc：mvc接口用例分离示例（不推荐）
+    tep：极速写法（强烈推荐）
+tests：测试用例
+utils：工具
+  fastapi_mock.py：自带fastapi项目
+  http_client.py：tep request猴子补丁
+  mitm.py：mitmproxy抓包自动生成用例
+.gitignore：Git忽略文件规则
+conf.yaml：项目配置
+conftest.py：pytest conftest
+pytest.ini：pytest配置
+"""
