@@ -61,52 +61,56 @@ def create_scaffold(project_name):
     def create_file(path, file_content=""):
         with open(path, "w", encoding="utf-8") as f:
             f.write(file_content)
-        msg = f"Created file: {path}"
+        msg = f"Created file:   {path}"
         print(msg)
 
     create_folder(project_name)
-    create_folder(os.path.join(project_name, "fixtures"))
-    create_folder(os.path.join(project_name, "fixtures", "second"))
-    create_folder(os.path.join(project_name, "fixtures", "second", "three"))
-    create_folder(os.path.join(project_name, "tests"))
     create_folder(os.path.join(project_name, "files"))
-    create_folder(os.path.join(project_name, "reports"))
-    create_folder(os.path.join(project_name, "utils"))
-    create_folder(os.path.join(project_name, "services"))
-
-    create_file(os.path.join(project_name, ".gitignore"), gitignore_content)
-    create_file(os.path.join(project_name, "conf.yaml"), conf_yaml_content)
-    create_file(os.path.join(project_name, "conftest.py"), conftest_content)
-    create_file(os.path.join(project_name, "pytest.ini"), pytest_ini_content)
+    create_folder(os.path.join(project_name, "fixtures"))
     create_file(os.path.join(project_name, "fixtures", "__init__.py"))
-    create_file(os.path.join(project_name, "fixtures", "fixture_admin.py"), fixture_admin_content)
     create_file(os.path.join(project_name, "fixtures", "fixture_env_vars.py"), fixture_env_vars_content)
     create_file(os.path.join(project_name, "fixtures", "fixture_login.py"), fixture_login_content)
-    create_file(os.path.join(project_name, "fixtures", "fixture_your_name.py"), fixture_your_name_content)
-    create_file(os.path.join(project_name, "fixtures", "second", "__init__.py"))
-    create_file(os.path.join(project_name, "fixtures", "second", "fixture_second.py"), fixture_second_content)
-    create_file(os.path.join(project_name, "fixtures", "second", "three", "__init__.py"))
-    create_file(os.path.join(project_name, "fixtures", "second", "three", "fixture_three.py"), fixture_three_content)
+    create_folder(os.path.join(project_name, "reports"))
+    create_folder(os.path.join(project_name, "samples"))
+    create_file(os.path.join(project_name, "samples", "__init__.py"))
+    create_folder(os.path.join(project_name, "samples", "db"))
+    create_file(os.path.join(project_name, "samples", "db", "__init__.py"))
+    create_file(os.path.join(project_name, "samples", "db", "test_mysql.py"), test_mysql_content)
+    create_folder(os.path.join(project_name, "samples", "http"))
+    create_file(os.path.join(project_name, "samples", "http", "__init__.py"))
+    create_file(os.path.join(project_name, "samples", "http", "test_request.py"), test_request_content)
+    create_file(os.path.join(project_name, "samples", "http", "test_request_monkey_patch.py"),
+                test_request_monkey_patch_content)
+    create_folder(os.path.join(project_name, "samples", "login_pay"))
+    create_file(os.path.join(project_name, "samples", "login_pay", "__init__.py"))
+    create_folder(os.path.join(project_name, "samples", "login_pay", "mvc"))
+    create_file(os.path.join(project_name, "samples", "login_pay", "mvc", "__init__.py"))
+    create_file(os.path.join(project_name, "samples", "login_pay", "mvc", "test_login_pay_mvc.py"),
+                test_login_pay_mvc_content)
+    create_folder(os.path.join(project_name, "samples", "login_pay", "mvc", "services"))
+    create_file(os.path.join(project_name, "samples", "login_pay", "mvc", "services", "__init__.py"))
+    create_file(os.path.join(project_name, "samples", "login_pay", "mvc", "services", "AddCart.py"), AddCart_content)
+    create_file(os.path.join(project_name, "samples", "login_pay", "mvc", "services", "Login.py"), Login_content)
+    create_file(os.path.join(project_name, "samples", "login_pay", "mvc", "services", "Order.py"), Order_content)
+    create_file(os.path.join(project_name, "samples", "login_pay", "mvc", "services", "Pay.py"), Pay_content)
+    create_file(os.path.join(project_name, "samples", "login_pay", "mvc", "services", "SearchSku.py"),
+                SearchSku_content)
+    create_folder(os.path.join(project_name, "samples", "login_pay", "tep"))
+    create_file(os.path.join(project_name, "samples", "login_pay", "tep", "__init__.py"))
+    create_file(os.path.join(project_name, "samples", "login_pay", "tep", "test_login.py"), test_login_content)
+    create_file(os.path.join(project_name, "samples", "login_pay", "tep", "test_login_pay.py"), test_login_pay_content)
+    create_folder(os.path.join(project_name, "tests"))
     create_file(os.path.join(project_name, "tests", "__init__.py"))
-    create_file(os.path.join(project_name, "tests", "test_login.py"), test_login_content)
-    create_file(os.path.join(project_name, "tests", "test_post.py"), test_post_content)
-    create_file(os.path.join(project_name, "tests", "test_mysql.py"), test_mysql_content)
-    create_file(os.path.join(project_name, "tests", "test_request.py"), test_request_content)
-    create_file(os.path.join(project_name, "tests", "test_login_pay.py"), test_login_pay_content)
-    create_file(os.path.join(project_name, "tests", "test_login_pay_httprunner.py"), test_login_pay_httprunner_content)
-    create_file(os.path.join(project_name, "tests", "test_login_pay_mvc.py"), test_login_pay_mvc_content)
-    create_file(os.path.join(project_name, "tests", "test_multi_fixture.py"), test_multi_fixture_content)
-    create_file(os.path.join(project_name, "tests", "test_request_monkey_patch.py"), test_request_monkey_patch_content)
+    create_folder(os.path.join(project_name, "utils"))
     create_file(os.path.join(project_name, "utils", "__init__.py"))
     create_file(os.path.join(project_name, "utils", "fastapi_mock.py"), fastapi_mock_content)
     create_file(os.path.join(project_name, "utils", "http_client.py"), http_client_content)
     create_file(os.path.join(project_name, "utils", "mitm.py"), mitm_content)
-    create_file(os.path.join(project_name, "services", "__init__.py"))
-    create_file(os.path.join(project_name, "services", "Login.py"), Login_content)
-    create_file(os.path.join(project_name, "services", "SearchSku.py"), SearchSku_content)
-    create_file(os.path.join(project_name, "services", "AddCart.py"), AddCart_content)
-    create_file(os.path.join(project_name, "services", "Order.py"), Order_content)
-    create_file(os.path.join(project_name, "services", "Pay.py"), Pay_content)
+    create_file(os.path.join(project_name, ".gitignore"), gitignore_content)
+    create_file(os.path.join(project_name, "conf.yaml"), conf_yaml_content)
+    create_file(os.path.join(project_name, "conftest.py"), conftest_content)
+    create_file(os.path.join(project_name, "pytest.ini"), pytest_ini_content)
+    create_file(os.path.join(project_name, "项目结构说明.txt"), structure_content)
 
     if ExtraArgument.create_venv:
         os.chdir(project_name)
